==> ivs-1.93.0-sources.jar: software/amazon/awscdk/services/ivs/StreamKeyProps.java <==
package software.amazon.awscdk.services.ivs;

/**
 * (experimental) Properties for creating a new Stream Key.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.24.0 (build b722f66)", date = "2021-03-11T13:46:21.823Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.ivs.$Module.class, fqn = "@aws-cdk/aws-ivs.StreamKeyProps")
@software.amazon.jsii.Jsii.Proxy(StreamKeyProps.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
public interface StreamKeyProps extends software.amazon.jsii.JsiiSerializable {

    /**
     * (experimental) Channel ARN for the stream.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.ivs.IChannel getChannel();

    /**
     * @return a {@link Builder} of {@link StreamKeyProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link StreamKeyProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public static final class Builder implements software.amazon.jsii.Builder<StreamKeyProps> {
        private software.amazon.awscdk.services.ivs.IChannel channel;

        /**
         * Sets the value of {@link StreamKeyProps#getChannel}
         * @param channel Channel ARN for the stream. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder channel(software.amazon.awscdk.services.ivs.IChannel channel) {
            this.channel = channel;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link StreamKeyProps}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        @Override
        public StreamKeyProps build() {
            return new Jsii$Proxy(channel);
        }
    }

    /**
     * An implementation for {@link StreamKeyProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements StreamKeyProps {
        private final software.amazon.awscdk.services.ivs.IChannel channel;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.channel = software.amazon.jsii.Kernel.get(this, "channel", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.ivs.IChannel.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final software.amazon.awscdk.services.ivs.IChannel channel) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.channel = java.util.Objects.requireNonNull(channel, "channel is required");
        }

        @Override
        public final software.amazon.awscdk.services.ivs.IChannel getChannel() {
            return this.channel;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            data.set("channel", om.valueToTree(this.getChannel()));

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@aws-cdk/aws-ivs.StreamKeyProps"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            StreamKeyProps.Jsii$Proxy that = (StreamKeyProps.Jsii$Proxy) o;

            return this.channel.equals(that.channel);
        }

        @Override
        public final int hashCode() {
            int result = this.channel.hashCode();
            return result;
        }
    }
}

==> ivs-1.182.0-sources.jar: software/amazon/awscdk/services/ivs/StreamKeyProps.java <==
package software.amazon.awscdk.services.ivs;

/**
 * (experimental) Properties for creating a new Stream Key.
 * <p>
 * Example:
 * <p>
 * <blockquote><pre>
 * // The code below shows an example of how to instantiate this type.
 * // The values are placeholders you should change.
 * import software.amazon.awscdk.services.ivs.*;
 * Channel channel;
 * StreamKeyProps streamKeyProps = StreamKeyProps.builder()
 *         .channel(channel)
 *         .build();
 * </pre></blockquote>
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.71.0 (build f1f58ae)", date = "2022-12-07T17:24:36.409Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.ivs.$Module.class, fqn = "@aws-cdk/aws-ivs.StreamKeyProps")
@software.amazon.jsii.Jsii.Proxy(StreamKeyProps.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
public interface StreamKeyProps extends software.amazon.jsii.JsiiSerializable {

    /**
     * (experimental) Channel ARN for the stream.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.ivs.IChannel getChannel();

    /**
     * @return a {@link Builder} of {@link StreamKeyProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link StreamKeyProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public static final class Builder implements software.amazon.jsii.Builder<StreamKeyProps> {
        software.amazon.awscdk.services.ivs.IChannel channel;

        /**
         * Sets the value of {@link StreamKeyProps#getChannel}
         * @param channel Channel ARN for the stream. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder channel(software.amazon.awscdk.services.ivs.IChannel channel) {
            this.channel = channel;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link StreamKeyProps}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        @Override
        public StreamKeyProps build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link StreamKeyProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements StreamKeyProps {
        private final software.amazon.awscdk.services.ivs.IChannel channel;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.channel = software.amazon.jsii.Kernel.get(this, "channel", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.ivs.IChannel.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.channel = java.util.Objects.requireNonNull(builder.channel, "channel is required");
        }

        @Override
        public final software.amazon.awscdk.services.ivs.IChannel getChannel() {
            return this.channel;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            data.set("channel", om.valueToTree(this.getChannel()));

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@aws-cdk/aws-ivs.StreamKeyProps"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            StreamKeyProps.Jsii$Proxy that = (StreamKeyProps.Jsii$Proxy) o;

            return this.channel.equals(that.channel);
        }

        @Override
        public final int hashCode() {
            int result = this.channel.hashCode();
            return result;
        }
    }
}
